@@ -1,5 +1,5 @@
 package Cwd;
-$VERSION = $VERSION = '2.14';
+$VERSION = $VERSION = '2.15';
 
 =head1 NAME
 
@@ -130,6 +130,12 @@ C<fast_abs_path()>.
 
 =back
 
+=head1 AUTHOR
+
+Originally by the perl5-porters.
+
+Now maintained by Ken Williams <KWILLIAMS@cpan.org>
+
 =head1 SEE ALSO
 
 L<File::chdir>
